﻿using Infragistics.Controls.Charts;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XamDiagram_Node_EditTemplate
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
        private void diagram_Loaded(object sender, RoutedEventArgs e)
        {
            // StackPanel
            var stackPanelFactory = new FrameworkElementFactory(typeof(StackPanel));
            stackPanelFactory.SetValue(StackPanel.MarginProperty, new Thickness(15.0));

            // TextBox
            var textBoxFactory = new FrameworkElementFactory(typeof(TextBox));
            textBoxFactory.SetValue(TextBox.BackgroundProperty, Brushes.Purple);
            textBoxFactory.SetValue(TextBox.ForegroundProperty, Brushes.White);
            textBoxFactory.SetBinding(
                TextBox.TextProperty, 
                new Binding { 
                    Path = new PropertyPath("Content"),
                    RelativeSource = new RelativeSource(RelativeSourceMode.FindAncestor, typeof(DiagramNode), 1),
                    Mode = BindingMode.TwoWay
                }
            );
            textBoxFactory.AddHandler(LoadedEvent, new RoutedEventHandler(textBoxLoadedEvent), true);

            // Grid
            var gridFactory = new FrameworkElementFactory(typeof(Grid));
            gridFactory.SetValue(Grid.BackgroundProperty, new SolidColorBrush(Colors.Green));
            gridFactory.SetValue(Grid.HeightProperty, 30.0);

            // StackPanel 内に TextBox を配置する。
            stackPanelFactory.AppendChild(textBoxFactory);
            // StackPanel 内に Grid を配置する。
            stackPanelFactory.AppendChild(gridFactory);
            
            var template = new DataTemplate { VisualTree = stackPanelFactory };

            var node = this.diagram.Items[0] as DiagramNode;
            // EditorTemplate に、StackPanel、TextBox、Grid を設定する。
            node.EditTemplate = template;
        }

        private void textBoxLoadedEvent(object sender, RoutedEventArgs e)
        {
            var textBox = sender as TextBox;
            textBox.Focus();
            textBox.SelectAll();
        }
    }
}
